@@ -12,12 +12,15 @@ from copy import deepcopy
 
 class HipChatLogger:
 
-    def __init__(self, auth_token, room_id, base_uri='https://api.hipchat.com/v2/', response_format='json'):
+    def __init__(self, auth_token, room_id, base_uri='https://api.hipchat.com/v2/', response_format='json' , http_proxy='' , https_proxy=''):
 
         self.auth_token = auth_token
         self.room_id = room_id
         self.base_uri = base_uri
         self.response_format = response_format
+        self.http_proxy = http_proxy
+        self.https_proxy = https_proxy
+        
 
     def __post(self, post_params, endpoint):
         """POST HTTP Request.
@@ -37,11 +40,21 @@ class HipChatLogger:
         __post_params = deepcopy(post_params)
 
         headers = {'content-type': 'application/json'}
+        
+        proxyDict = {}
+        
+        if self.http_proxy:
+            proxyDict["http"] = self.http_proxy
+        if self.https_proxy:
+            proxyDict["https"] = self.https_proxy
 
         uri = self.base_uri + endpoint + '?auth_token=' + self.auth_token
+        
+        if not proxyDict:
+            proxyDict = None
 
         http = requests.session()
-        response = http.post(uri, data=json.dumps(__post_params), headers=headers)
+        response = http.post(uri, data=json.dumps(__post_params), headers=headers , proxies=proxyDict)
         http.close()
 
         return response
